summaryrefslogtreecommitdiffstats
path: root/kword/KWPartFrameSet.h
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWPartFrameSet.h')
-rw-r--r--kword/KWPartFrameSet.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kword/KWPartFrameSet.h b/kword/KWPartFrameSet.h
index 25609c1a..d486b298 100644
--- a/kword/KWPartFrameSet.h
+++ b/kword/KWPartFrameSet.h
@@ -53,7 +53,7 @@ public:
void setChild( KWDocumentChild* child );
/**
* Update the tqgeometry of m_child based on the tqgeometry of the frame.
*/
void updateChildGeometry();
@@ -157,7 +157,7 @@ public:
KWDocument* parent()const
{ return m_pKWordDoc; }
- virtual void setDocument( KoDocument *doc, const TQRect &tqgeometry );
+ virtual void setDocument( KoDocument *doc, const TQRect &geometry );
void setPartFrameSet( KWPartFrameSet* fs ) { m_partFrameSet = fs; }
KWPartFrameSet * partFrameSet() const { return m_partFrameSet; }
@@ -53,7 +53,7 @@ public:
void setChild( KWDocumentChild* child );
/**
- * Update the tqgeometry of m_child based on the tqgeometry of the frame.
+ * Update the geometry of m_child based on the geometry of the frame.
*/
void updateChildGeometry();